@@ -2,7 +2,7 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { Session, TerminalAPI } from '@jupyterlab/services';
+import type { Kernel, Session, TerminalAPI, User } from '@jupyterlab/services';
 import {
   test as base,
   Page,
@@ -56,6 +56,27 @@ export type GalataOptions = {
    * Default: true
    */
   autoGoto: boolean;
+  /**
+   * Kernels created during the test.
+   *
+   * Possible values are:
+   * - null: The kernels API won't be mocked
+   * - Map<string, Kernel.IModel>: The kernels created during a test.
+   *
+   * By default the kernels created during a test will be tracked and disposed at the end.
+   */
+  kernels: Map<string, Kernel.IModel> | null;
+  /**
+   * Mock JupyterLab config in-memory or not.
+   *
+   * Possible values are:
+   * - true (default): JupyterLab config will be mocked on a per test basis
+   * - false: JupyterLab config won't be mocked (Be careful it will write config in local files)
+   * - Record<string, JSONObject>: Initial JupyterLab data config - Mapping (config section, value).
+   *
+   * By default the config is stored in-memory.
+   */
+  mockConfig: boolean | Record<string, unknown>;
   /**
    * Mock JupyterLab state in-memory or not.
    *
@@ -81,6 +102,17 @@ export type GalataOptions = {
    * they are still initialized with the hard drive values.
    */
   mockSettings: boolean | Record<string, unknown>;
+  /**
+   * Mock JupyterLab user in-memory or not.
+   *
+   * Possible values are:
+   * - true (default): JupyterLab user will be mocked on a per test basis
+   * - false: JupyterLab user won't be mocked (It will be a random user so snapshots won't match)
+   * - Record<string, unknown>: Initial JupyterLab user - Mapping (user attribute, value).
+   *
+   * By default the user is stored in-memory.
+   */
+  mockUser: boolean | Partial<User.IUser>;
   /**
    * Galata can keep the uploaded and created files in ``tmpPath`` on
    * the server root for debugging purpose. By default the files are
@@ -149,7 +181,7 @@ export const test: TestType<
    *
    * Default: /lab
    */
-  appPath: '/lab',
+  appPath: ['/lab', { option: true }],
   /**
    * Whether to go to JupyterLab page within the fixture or not.
    *
@@ -157,7 +189,36 @@ export const test: TestType<
    *
    * Note: Setting it to false allows to register new route mock-ups for example.
    */
-  autoGoto: true,
+  autoGoto: [true, { option: true }],
+  /**
+   * Kernels created during the test.
+   *
+   * Possible values are:
+   * - null: The kernels API won't be mocked
+   * - Map<string, Kernel.IModel>: The kernels created during a test.
+   *
+   * By default the kernels created during a test will be tracked and disposed at the end.
+   */
+  kernels: async ({ request }, use) => {
+    const kernels = new Map<string, Kernel.IModel>();
+
+    await use(kernels);
+
+    if (kernels.size > 0) {
+      await galata.Mock.clearRunners(request, [...kernels.keys()], 'kernels');
+    }
+  },
+  /**
+   * Mock JupyterLab config in-memory or not.
+   *
+   * Possible values are:
+   * - true (default): JupyterLab config will be mocked on a per test basis
+   * - false: JupyterLab config won't be mocked (Be careful it will write config in local files)
+   * - Record<string, JSONObject>: Initial JupyterLab data config - Mapping (config section, value).
+   *
+   * By default the config is stored in-memory.
+   */
+  mockConfig: [true, { option: true }],
   /**
    * Mock JupyterLab state in-memory or not.
    *
@@ -168,7 +229,7 @@ export const test: TestType<
    *
    * By default the state is stored in-memory
    */
-  mockState: true,
+  mockState: [true, { option: true }],
   /**
    * Mock JupyterLab settings in-memory or not.
    *
@@ -182,7 +243,18 @@ export const test: TestType<
    * By default the settings are stored in-memory. However the
    * they are still initialized with the hard drive values.
    */
-  mockSettings: galata.DEFAULT_SETTINGS,
+  mockSettings: [galata.DEFAULT_SETTINGS, { option: true }],
+  /**
+   * Mock JupyterLab user in-memory or not.
+   *
+   * Possible values are:
+   * - true (default): JupyterLab user will be mocked on a per test basis
+   * - false: JupyterLab user won't be mocked (It will be a random user so snapshots won't match)
+   * - Record<string, unknown>: Initial JupyterLab user - Mapping (user attribute, value).
+   *
+   * By default the user is stored in-memory.
+   */
+  mockUser: [true, { option: true }],
   /**
    * Galata can keep the uploaded and created files in ``tmpPath`` on
    * the server root for debugging purpose. By default the files are
@@ -192,7 +264,7 @@ export const test: TestType<
    * - 'on' - ``tmpPath`` is never deleted
    * - 'only-on-failure' - ``tmpPath`` is deleted except if a test failed or timed out.
    */
-  serverFiles: 'off',
+  serverFiles: ['off', { option: true }],
   /**
    * Sessions created during the test.
    *
@@ -202,17 +274,13 @@ export const test: TestType<
    *
    * By default the sessions created during a test will be tracked and disposed at the end.
    */
-  sessions: async ({ baseURL }, use) => {
+  sessions: async ({ request }, use) => {
     const sessions = new Map<string, Session.IModel>();
 
     await use(sessions);
 
     if (sessions.size > 0) {
-      await galata.Mock.clearRunners(
-        baseURL!,
-        [...sessions.keys()],
-        'sessions'
-      );
+      await galata.Mock.clearRunners(request, [...sessions.keys()], 'sessions');
     }
   },
   /**
@@ -220,18 +288,18 @@ export const test: TestType<
    *
    * Possible values are:
    * - null: The Terminals API won't be mocked
-   * - Map<string, TerminalsAPI.IModel>: The Terminals created during a test.
+   * - Map<string, TerminalAPI.IModel>: The Terminals created during a test.
    *
    * By default the Terminals created during a test will be tracked and disposed at the end.
    */
-  terminals: async ({ baseURL }, use) => {
+  terminals: async ({ request }, use) => {
     const terminals = new Map<string, TerminalAPI.IModel>();
 
     await use(terminals);
 
     if (terminals.size > 0) {
       await galata.Mock.clearRunners(
-        baseURL!,
+        request,
         [...terminals.keys()],
         'terminals'
       );
@@ -243,13 +311,13 @@ export const test: TestType<
    * Note: if you override this string, you will need to take care of creating the
    * folder and cleaning it.
    */
-  tmpPath: async ({ baseURL, serverFiles, request }, use, testInfo) => {
+  tmpPath: async ({ request, serverFiles }, use, testInfo) => {
     // Remove appended retry part for reproducibility
     const testFolder = path
       .basename(testInfo.outputDir)
       .replace(/-retry\d+$/i, '');
 
-    const contents = new ContentsHelper(baseURL!, undefined, request);
+    const contents = new ContentsHelper(request);
 
     if (await contents.directoryExists(testFolder)) {
       await contents.deleteDirectory(testFolder);
@@ -281,13 +349,10 @@ export const test: TestType<
       page: Page,
       helpers: IJupyterLabPage
     ): Promise<void> => {
-      await page.waitForSelector('#jupyterlab-splash', {
-        state: 'detached'
-      });
+      await page.locator('#jupyterlab-splash').waitFor({ state: 'detached' });
       await helpers.waitForCondition(() => {
         return helpers.activity.isTabActive('Launcher');
       });
-
       // Oddly current tab is not always set to active
       if (!(await helpers.isInSimpleMode())) {
         await helpers.activity.activateTab('Launcher');
@@ -316,8 +381,11 @@ export const test: TestType<
       appPath,
       autoGoto,
       baseURL,
+      kernels,
+      mockConfig,
       mockSettings,
       mockState,
+      mockUser,
       page,
       sessions,
       terminals,
@@ -331,13 +399,16 @@ export const test: TestType<
         appPath,
         autoGoto,
         baseURL!,
+        mockConfig,
         mockSettings,
         mockState,
+        mockUser,
         page,
         sessions,
         terminals,
         tmpPath,
-        waitForApplication
+        waitForApplication,
+        kernels
       )
     );
   }
