@@ -2,7 +2,6 @@
 // Distributed under the terms of the Modified BSD License.
 
 import { expect, IJupyterLabPageFixture, test } from '@jupyterlab/galata';
-import { setSidebarWidth } from './utils';
 
 const fileName = 'notebook.ipynb';
 
@@ -81,9 +80,9 @@ test.describe('Notebook Toolbar', () => {
     await page.notebook.clickToolbarItem('insert');
     await page.notebook.selectCells(2);
     await page.notebook.clickToolbarItem('insert');
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Copy-Paste cell', async ({ page }) => {
@@ -92,18 +91,18 @@ test.describe('Notebook Toolbar', () => {
     await page.notebook.clickToolbarItem('copy');
     await page.notebook.selectCells(0);
     await page.notebook.clickToolbarItem('paste');
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Cut cell', async ({ page }) => {
     const imageName = 'cut-cell.png';
     await page.notebook.selectCells(1);
     await page.notebook.clickToolbarItem('cut');
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Paste cell', async ({ page }) => {
@@ -114,21 +113,21 @@ test.describe('Notebook Toolbar', () => {
     const imageName = 'paste-cell.png';
     await page.notebook.selectCells(1);
     await page.notebook.clickToolbarItem('paste');
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    await expect
-      .soft(page.locator('.jp-Notebook-cell.jp-mod-active .jp-cell-toolbar'))
-      .toBeVisible();
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    await expect(
+      page.locator('.jp-Notebook-cell.jp-mod-active .jp-cell-toolbar')
+    ).toBeVisible();
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Delete cells', async ({ page }) => {
     const imageName = 'delete-cell.png';
     await page.notebook.selectCells(1, 2);
     await page.menu.clickMenuItem('Edit>Delete Cells');
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Run cell', async ({ page }) => {
@@ -136,11 +135,11 @@ test.describe('Notebook Toolbar', () => {
     await page.notebook.selectCells(2);
 
     await page.notebook.clickToolbarItem('run');
-    await page.waitForSelector('text=8');
+    await page.getByText('8', { exact: true }).waitFor();
 
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 
   test('Change cell type to Markdown', async ({ page }) => {
@@ -150,9 +149,9 @@ test.describe('Notebook Toolbar', () => {
     await page.keyboard.press('m');
     await page.keyboard.press('Enter');
     await page.notebook.selectCells(2);
-    const nbPanel = await page.notebook.getNotebookInPanel();
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
 
-    expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
   });
 });
 
@@ -160,19 +159,19 @@ test('Toolbar items act on owner widget', async ({ page }) => {
   // Given two side-by-side notebooks and the second being active
   const file1 = 'notebook1.ipynb';
   await page.notebook.createNew(file1);
-  const panel1 = await page.activity.getPanel(file1);
-  const tab1 = await page.activity.getTab(file1);
+  const panel1 = await page.activity.getPanelLocator(file1);
+  const tab1 = page.activity.getTabLocator(file1);
 
   // FIXME Calling a second time `page.notebook.createNew` is not robust
   await page.menu.clickMenuItem('File>New>Notebook');
   try {
-    await page.waitForSelector('.jp-Dialog', { timeout: 5000 });
+    await page.locator('.jp-Dialog').waitFor({ timeout: 5000 });
     await page.click('.jp-Dialog .jp-mod-accept');
   } catch (reason) {
     // no-op
   }
 
-  const tab2 = await page.activity.getTab();
+  const tab2 = page.activity.getTabLocator();
 
   const tab2BBox = await tab2.boundingBox();
   await page.mouse.move(
@@ -187,9 +186,10 @@ test('Toolbar items act on owner widget', async ({ page }) => {
   expect(classlist.split(' ')).not.toContain('jp-mod-current');
 
   // When clicking on toolbar item of the first file
-  await (
-    await panel1.$('jp-button[data-command="notebook:insert-cell-below"]')
-  ).click();
+  await panel1
+    ?.locator('jp-button[data-command="notebook:insert-cell-below"]')
+    .first()
+    .click();
 
   // Then the first file is activated and the action is performed
   const classlistEnd = await tab1.getAttribute('class');
@@ -206,12 +206,12 @@ test.describe('Reactive toolbar', () => {
     page
   }) => {
     const toolbar = page.locator('.jp-NotebookPanel-toolbar');
-    await expect(toolbar.locator('.jp-Toolbar-item:visible')).toHaveCount(14);
+    await expect(toolbar.locator('.jp-Toolbar-item:visible')).toHaveCount(15);
     await expect(
       toolbar.locator('.jp-Toolbar-responsive-opener')
     ).not.toBeVisible();
 
-    await setSidebarWidth(page, 520);
+    await page.sidebar.setWidth(520);
 
     await expect(
       toolbar.locator('.jp-Toolbar-responsive-opener')
@@ -225,7 +225,7 @@ test.describe('Reactive toolbar', () => {
   }) => {
     const toolbar = page.locator('.jp-NotebookPanel-toolbar');
 
-    await setSidebarWidth(page, 520);
+    await page.sidebar.setWidth(520);
 
     await toolbar.locator('.jp-Toolbar-responsive-opener').click();
 
@@ -236,12 +236,13 @@ test.describe('Reactive toolbar', () => {
       'body > .jp-Toolbar-responsive-popup:visible'
     );
     const popupToolbarItems = popupToolbar.locator('.jp-Toolbar-item:visible');
-    await expect(popupToolbarItems).toHaveCount(3);
+    await expect(popupToolbarItems).toHaveCount(4);
 
     const itemChildClasses = [
       '.jp-DebuggerBugButton',
       '.jp-Toolbar-kernelName',
-      '.jp-Notebook-ExecutionIndicator'
+      '.jp-Notebook-ExecutionIndicator',
+      '[data-command="notebook:toggle-virtual-scrollbar"]'
     ];
 
     for (let i = 0; i < (await popupToolbarItems.count()); i++) {
@@ -275,7 +276,7 @@ test.describe('Reactive toolbar', () => {
       'cellType'
     );
 
-    await setSidebarWidth(page, 600);
+    await page.sidebar.setWidth(600);
     await toolbar.locator('.jp-Toolbar-responsive-opener').click();
 
     // A 'visible' selector is added because there is another response popup element
@@ -288,7 +289,7 @@ test.describe('Reactive toolbar', () => {
 
     await expect(popupToolbarItems.nth(1)).toHaveText('new item 1');
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
     const toolbarItems = toolbar.locator('.jp-Toolbar-item:visible');
     await expect(toolbarItems.nth(10)).toHaveText('new item 1');
   });
@@ -298,7 +299,7 @@ test.describe('Reactive toolbar', () => {
   }) => {
     const toolbar = page.locator('.jp-NotebookPanel-toolbar');
 
-    await setSidebarWidth(page, 600);
+    await page.sidebar.setWidth(600);
 
     await addWidgetsInNotebookToolbar(
       page,
@@ -319,4 +320,26 @@ test.describe('Reactive toolbar', () => {
 
     await expect(popupToolbarItems.nth(1)).toHaveText('new item 1');
   });
+
+  test('Item should be correctly removed on ignoring', async ({ page }) => {
+    const toolbar = page.locator('.jp-NotebookPanel-toolbar');
+    const imageName = 'toolbar-items.png';
+    await page.evaluate(async () => {
+      await window.jupyterapp.commands.execute('settingeditor:open', {
+        query: 'Notebook Panel'
+      });
+    });
+
+    // Ignore Save
+    const checkboxLabel = page
+      .locator('div.checkbox >> text=Whether the item is ignored or not')
+      .first();
+    await checkboxLabel.click();
+
+    await page.locator('div.lm-TabBar-tabLabel >> text=Notebook.ipynb').click();
+    const saveLocator = toolbar.locator('[data-jp-item-name="save"]');
+    await expect(saveLocator).toHaveCount(0, { timeout: 1000 });
+
+    expect(await toolbar.screenshot()).toMatchSnapshot(imageName);
+  });
 });
