@@ -19,6 +19,7 @@ from jupyterlab_server import (
     WorkspaceImportApp,
     WorkspaceListApp,
 )
+from jupyterlab_server.config import get_static_page_config
 from notebook_shim.shim import NotebookConfigShimMixin
 from traitlets import Bool, Instance, Type, Unicode, default
 
@@ -43,6 +44,7 @@ from .commands import (
 from .coreconfig import CoreConfig
 from .debuglog import DebugLogFileMixin
 from .extensions import MANAGERS as EXT_MANAGERS
+from .extensions.manager import PluginManager
 from .extensions.readonly import ReadOnlyExtensionManager
 from .handlers.announcements import (
     CheckForUpdate,
@@ -55,6 +57,7 @@ from .handlers.announcements import (
 from .handlers.build_handler import Builder, BuildHandler, build_path
 from .handlers.error_handler import ErrorHandler
 from .handlers.extension_manager_handler import ExtensionHandler, extensions_handler_path
+from .handlers.plugin_manager_handler import PluginHandler, plugins_handler_path
 
 DEV_NOTE = """You're running JupyterLab from source.
 If you're working on the TypeScript sources of JupyterLab, try running
@@ -186,12 +189,12 @@ class LabBuildApp(JupyterApp, DebugLogFileMixin):
             core_config=self.core_config,
             splice_source=self.splice_source,
         )
-        self.log.info("JupyterLab %s", version)
+        self.log.info(f"JupyterLab {version}")
         with self.debug_logging():
             if self.pre_clean:
-                self.log.info("Cleaning %s" % app_dir)
+                self.log.info(f"Cleaning {app_dir}")
                 clean(app_options=app_options)
-            self.log.info("Building in %s", app_dir)
+            self.log.info(f"Building in {app_dir}")
             try:
                 production = None if self.dev_build is None else not self.dev_build
                 build(
@@ -214,7 +217,7 @@ ext_warn_msg = "WARNING: this will delete all of your extensions, which will nee
 clean_flags = dict(base_flags)
 clean_flags["extensions"] = (
     {"LabCleanApp": {"extensions": True}},
-    "Also delete <app-dir>/extensions.\n%s" % ext_warn_msg,
+    f"Also delete <app-dir>/extensions.\n{ext_warn_msg}",
 )
 clean_flags["settings"] = (
     {"LabCleanApp": {"settings": True}},
@@ -226,7 +229,7 @@ clean_flags["static"] = (
 )
 clean_flags["all"] = (
     {"LabCleanApp": {"all": True}},
-    "Delete the entire contents of the app directory.\n%s" % ext_warn_msg,
+    f"Delete the entire contents of the app directory.\n{ext_warn_msg}",
 )
 
 
@@ -255,9 +258,7 @@ class LabCleanApp(JupyterApp):
 
     app_dir = Unicode("", config=True, help="The app directory to clean")
 
-    extensions = Bool(
-        False, config=True, help="Also delete <app-dir>/extensions.\n%s" % ext_warn_msg
-    )
+    extensions = Bool(False, config=True, help=f"Also delete <app-dir>/extensions.\n{ext_warn_msg}")
 
     settings = Bool(False, config=True, help="Also delete <app-dir>/settings")
 
@@ -266,7 +267,7 @@ class LabCleanApp(JupyterApp):
     all = Bool(
         False,
         config=True,
-        help="Delete the entire contents of the app directory.\n%s" % ext_warn_msg,
+        help=f"Delete the entire contents of the app directory.\n{ext_warn_msg}",
     )
 
     def start(self):
@@ -298,9 +299,9 @@ class LabPathApp(JupyterApp):
     """
 
     def start(self):
-        print("Application directory:   %s" % get_app_dir())
-        print("User Settings directory: %s" % get_user_settings_dir())
-        print("Workspaces directory: %s" % get_workspaces_dir())
+        print(f"Application directory:   {get_app_dir()}")
+        print(f"User Settings directory: {get_user_settings_dir()}")
+        print(f"Workspaces directory: {get_workspaces_dir()}")
 
 
 class LabWorkspaceExportApp(WorkspaceExportApp):
@@ -493,6 +494,10 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
 
         This flag is now deprecated and will be removed in JupyterLab v5.""",
     )
+    flags["custom-css"] = (
+        {"LabApp": {"custom_css": True}},
+        "Load custom CSS in template html files. Default is False",
+    )
 
     subcommands = {
         "build": (LabBuildApp, LabBuildApp.description.splitlines()[0]),
@@ -578,6 +583,14 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
         help="Whether to expose the global app instance to browser via window.jupyterapp",
     )
 
+    custom_css = Bool(
+        False,
+        config=True,
+        help="""Whether custom CSS is loaded on the page.
+    Defaults to False.
+    """,
+    )
+
     collaborative = Bool(
         False,
         config=True,
@@ -596,6 +609,12 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
         config=True,
     )
 
+    lock_all_plugins = Bool(
+        False,
+        config=True,
+        help="Whether all plugins are locked (cannot be enabled/disabled from the UI)",
+    )
+
     check_for_updates_class = Type(
         default_value=CheckForUpdate,
         klass=CheckForUpdateABC,
@@ -702,32 +721,52 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
             self.static_paths = [self.static_dir]
             self.template_paths = [self.templates_dir]
 
+    def _prepare_templates(self):
+        super()._prepare_templates()
+        self.jinja2_env.globals.update(custom_css=self.custom_css)
+
     def initialize_handlers(self):  # noqa
         handlers = []
 
         # Set config for Jupyterlab
         page_config = self.serverapp.web_app.settings.setdefault("page_config_data", {})
+        page_config.update(get_static_page_config(logger=self.log, level="all"))
+
         page_config.setdefault("buildAvailable", not self.core_mode and not self.dev_mode)
         page_config.setdefault("buildCheck", not self.core_mode and not self.dev_mode)
         page_config["devMode"] = self.dev_mode
-        page_config["token"] = self.serverapp.token
+        page_config["token"] = self.serverapp.identity_provider.token
         page_config["exposeAppInBrowser"] = self.expose_app_in_browser
         page_config["quitButton"] = self.serverapp.quit_button
         page_config["allow_hidden_files"] = self.serverapp.contents_manager.allow_hidden
+        if hasattr(self.serverapp.contents_manager, "delete_to_trash"):
+            page_config["delete_to_trash"] = self.serverapp.contents_manager.delete_to_trash
 
         # Client-side code assumes notebookVersion is a JSON-encoded string
         page_config["notebookVersion"] = json.dumps(jpserver_version_info)
 
-        self.log.info("JupyterLab extension loaded from %s" % HERE)
-        self.log.info("JupyterLab application directory is %s" % self.app_dir)
+        self.log.info(f"JupyterLab extension loaded from {HERE!s}")
+        self.log.info(f"JupyterLab application directory is {self.app_dir!s}")
 
-        build_handler_options = AppOptions(
+        if self.custom_css:
+            handlers.append(
+                (
+                    r"/custom/(.*)(?<!\.js)$",
+                    self.serverapp.web_app.settings["static_handler_class"],
+                    {
+                        "path": self.serverapp.web_app.settings["static_custom_path"],
+                        "no_cache_paths": ["/"],  # don't cache anything in custom
+                    },
+                )
+            )
+
+        app_options = AppOptions(
             logger=self.log,
             app_dir=self.app_dir,
             labextensions_path=self.extra_labextensions_path + self.labextensions_path,
             splice_source=self.splice_source,
         )
-        builder = Builder(self.core_mode, app_options=build_handler_options)
+        builder = Builder(self.core_mode, app_options=app_options)
         build_handler = (build_path, BuildHandler, {"builder": builder})
         handlers.append(build_handler)
 
@@ -755,7 +794,7 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
             if self.dev_mode:
                 watch_dev(self.log)
             else:
-                watch(app_options=build_handler_options)
+                watch(app_options=app_options)
                 page_config["buildAvailable"] = False
             self.cache_files = False
 
@@ -798,14 +837,14 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
                 self.log.debug(f"Extension manager will be constrained by {listings_config}")
 
             try:
-                ext_manager = manager_factory(build_handler_options, listings_config, self)
+                ext_manager = manager_factory(app_options, listings_config, self)
                 metadata = dataclasses.asdict(ext_manager.metadata)
             except Exception as err:
                 self.log.warning(
                     f"Failed to instantiate the extension manager {provider}. Falling back to read-only manager.",
                     exc_info=err,
                 )
-                ext_manager = ReadOnlyExtensionManager(build_handler_options, listings_config, self)
+                ext_manager = ReadOnlyExtensionManager(app_options, listings_config, self)
                 metadata = dataclasses.asdict(ext_manager.metadata)
 
             page_config["extensionManager"] = metadata
@@ -816,6 +855,27 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
             )
             handlers.append(ext_handler)
 
+            # Add plugin manager handlers
+            lock_rules = frozenset(
+                {rule for rule, value in page_config.get("lockedExtensions", {}).items() if value}
+            )
+            handlers.append(
+                (
+                    plugins_handler_path,
+                    PluginHandler,
+                    {
+                        "manager": PluginManager(
+                            app_options=app_options,
+                            ext_options={
+                                "lock_rules": lock_rules,
+                                "all_locked": self.lock_all_plugins,
+                            },
+                            parent=self,
+                        )
+                    },
+                )
+            )
+
             # Add announcement handlers
             page_config["news"] = {"disabled": self.news_url is None}
             handlers.extend(
@@ -869,13 +929,14 @@ class LabApp(NotebookConfigShimMixin, LabServerApp):
                 import jupyter_collaboration  # noqa
             except ImportError:
                 self.log.critical(
-                    """
-To enable real-time collaboration, you must install the extension `jupyter_collaboration`.
-You can install it using pip for example:
+                    """\
+Jupyter Lab cannot start, because `jupyter_collaboration` was configured but cannot be `import`ed.
 
-  python -m pip install jupyter_collaboration
+To fix this, either:
 
-This flag is now deprecated and will be removed in JupyterLab v5.
+1) install the extension `jupyter-collaboration`; for example: `python -m pip install jupyter-collaboration`
+
+2) disable collaboration; for example, remove the `--collaborative` flag from the commandline.  To see more ways to adjust the collaborative behavior, see https://jupyterlab-realtime-collaboration.readthedocs.io/en/latest/configuration.html .
 """
                 )
                 sys.exit(1)
